==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebActivePaneEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebActivePaneEventArgsDescription } from "./WebActivePaneEventArgsDescription";
/**
 * @hidden
 */
var WebActivePaneEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebActivePaneEventArgsDescriptionMetadata, _super);
    function WebActivePaneEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActivePaneEventArgsDescriptionMetadata.b = function (a) {
        if (WebActivePaneEventArgsDescriptionMetadata.a == null) {
            WebActivePaneEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActivePaneEventArgsDescriptionMetadata.c(WebActivePaneEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebActivePaneEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebActivePaneEventArgsDescriptionMetadata.a);
        WebContentPaneDescriptionMetadata.d(a);
    };
    WebActivePaneEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActivePaneEventArgs");
        a.item("NewPane", "ExportedType:WebContentPane");
        a.item("OldPane", "ExportedType:WebContentPane");
    };
    WebActivePaneEventArgsDescriptionMetadata.d = function (a) {
        WebActivePaneEventArgsDescriptionMetadata.b(a);
        a.aa("WebActivePaneEventArgs", function () { return new WebActivePaneEventArgsDescription(); });
        a.z("WebActivePaneEventArgs", WebActivePaneEventArgsDescriptionMetadata.a);
    };
    WebActivePaneEventArgsDescriptionMetadata.$t = markType(WebActivePaneEventArgsDescriptionMetadata, 'WebActivePaneEventArgsDescriptionMetadata');
    WebActivePaneEventArgsDescriptionMetadata.a = null;
    return WebActivePaneEventArgsDescriptionMetadata;
}(Base));
export { WebActivePaneEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm5/lib/WebActivePaneEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebActivePaneEventArgsDescription } from "./WebActivePaneEventArgsDescription";
/**
 * @hidden
 */
var WebActivePaneEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebActivePaneEventArgsDescriptionMetadata, _super);
    function WebActivePaneEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActivePaneEventArgsDescriptionMetadata.b = function (a) {
        if (WebActivePaneEventArgsDescriptionMetadata.a == null) {
            WebActivePaneEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActivePaneEventArgsDescriptionMetadata.c(WebActivePaneEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebActivePaneEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebActivePaneEventArgsDescriptionMetadata.a);
        WebContentPaneDescriptionMetadata.d(a);
    };
    WebActivePaneEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActivePaneEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("NewPane", "ExportedType:WebContentPane");
        a.item("OldPane", "ExportedType:WebContentPane");
    };
    WebActivePaneEventArgsDescriptionMetadata.d = function (a) {
        WebActivePaneEventArgsDescriptionMetadata.b(a);
        a.ac("WebActivePaneEventArgs", function () { return new WebActivePaneEventArgsDescription(); });
        a.ab("WebActivePaneEventArgs", WebActivePaneEventArgsDescriptionMetadata.a);
    };
    WebActivePaneEventArgsDescriptionMetadata.$t = markType(WebActivePaneEventArgsDescriptionMetadata, 'WebActivePaneEventArgsDescriptionMetadata');
    WebActivePaneEventArgsDescriptionMetadata.a = null;
    return WebActivePaneEventArgsDescriptionMetadata;
}(Base));
export { WebActivePaneEventArgsDescriptionMetadata };
